@@ -3,8 +3,9 @@
 
   var settings = {
         callback: $.noop,
+        deep_linking: true,
         init: false
-      }, 
+      },
 
       methods = {
         init : function (options) {
@@ -12,6 +13,8 @@
 
           return this.each(function () {
             if (!settings.init) methods.events();
+
+            if (settings.deep_linking) methods.from_hash();
           });
         },
 
@@ -31,7 +34,7 @@
 
           if (hasHash && $content.length > 0) {
             // Show tab content
-            e.preventDefault();
+            if (e && !settings.deep_linking) e.preventDefault();
             $content.closest('.tabs-content').children('li').removeClass('active').hide();
             $content.css('display', 'block').addClass('active');
           }
@@ -41,6 +44,13 @@
           $tab.addClass('active');
 
           settings.callback();
+        },
+
+        from_hash : function () {
+          var hash = window.location.hash,
+              $tab = $('a[href="' + hash + '"]');
+
+          $tab.trigger('click.fndtn');
         }
       }
 
@@ -50,7 +60,7 @@
     } else if (typeof method === 'object' || !method) {
       return methods.init.apply(this, arguments);
     } else {
-      $.error('Method ' +  method + ' does not exist on jQuery.foundationTooltips');
+      $.error('Method ' +  method + ' does not exist on jQuery.foundationTabs');
     }
   };
 }(jQuery, this, this.document));
\ No newline at end of file
